/* Copyright Notice:
 * -----------------
 *
 * The contents of this file are subject to the Pathfinder Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.pathfinder-xquery.org/license
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the Pathfinder system.
 *
 * The Original Code has initially been developed by the Database &
 * Information Systems Group at the University of Konstanz, Germany and
 * the Database Group at the Technische Universitaet Muenchen, Germany.
 * It is now maintained by the Database Systems Group at the Eberhard
 * Karls Universitaet Tuebingen, Germany.  Portions created by the
 * University of Konstanz, the Technische Universitaet Muenchen, and the
 * Universitaet Tuebingen are Copyright (C) 2000-2005 University of
 * Konstanz, (C) 2005-2008 Technische Universitaet Muenchen, and (C)
 * 2008-2011 Eberhard Karls Universitaet Tuebingen, respectively.  All
 * Rights Reserved.
 *
 *//**
 *
 * @file
 * 
 * Some Convenience-Wrappers around the libxml2-xpath API 
 *
 */

#ifndef LIBXML_XPATH_UTILS_H
#define LIBXML_XPATH_UTILS_H

#include <stdio.h>
#ifdef HAVE_STDBOOL_H
    #include <stdbool.h>
#endif

/* SAX parser interface (libxml2) */
#include <libxml/parser.h>
#include <libxml/parserInternals.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <libxml/xpathInternals.h>

void
PFxml2la_xpath_init(void);

void
PFxml2la_xpath_free(void);

xmlXPathObjectPtr 
PFxml2la_xpath_evalXPathFromDocCtx(xmlXPathContextPtr xpathCtx, 
                                   const char* xpathExpression);

xmlXPathObjectPtr 
PFxml2la_xpath_evalXPathFromNodeCtx(xmlXPathContextPtr docXPathCtx, 
                     xmlNodePtr nodeXpathCtx, 
                     const char* xpathExpression);

int 
PFxml2la_xpath_getNodeCount(xmlXPathObjectPtr xpathObjPtr);

xmlNodePtr 
PFxml2la_xpath_getNthNode(xmlXPathObjectPtr xpathObjPtr, int n);


char* 
PFxml2la_xpath_getAttributeValueFromElementNode(xmlNodePtr nodePtr, 
                                                const char* attributeName);

char* 
PFxml2la_xpath_getAttributeValueFromAttributeNode(xmlNodePtr nodePtr);

PFarray_t *
PFxml2la_xpath_getAttributeValuesFromAttributeNodes(
    xmlXPathObjectPtr xpathObjectPtr);

char* 
PFxml2la_xpath_getElementValue(xmlNodePtr nodePtr);

int 
PFxml2la_xpath_getIntValue(char* s);

double 
PFxml2la_xpath_getFloatValue(char* s);

bool 
PFxml2la_xpath_getBoolValue(char* s);

char*
PFxml2la_xpath_getStrValue(xmlXPathObjectPtr xpathObjPtr);

#endif
